#!/bin/bash
# Description: This file is the network performance diagnostic test script for 
# the pNFS regression suite and performance debugging tool chain. It calculates the performance of the link between all the nodes.
# Stage: 0 
# Author: Zainul Abedin (zja) & Swaroop Choudhari (svchoudh)
# Inputs: 
# Detailed Description: 
# Stage0 of the test suite is used to get Experimental setup information. 

export RSH=ssh
count="0"
min_filesize=$1
max_filesize=$2
record_size=$3

declare -a mount_points

if (([ -s "$client_list" ]) && ([ -r "$client_list" ]))
    then
    if (([ -s "$mount_point_list" ]) && ([ -r "$mount_point_list" ]))
	then
	for mount_point in `cat "$mount_point_list"`; do
	    mount_points[i]=$mount_point
	    let "i=$i+1"
	done
    else
	#output error and exit
	echo "ERROR reading mount point list of clients:" $mount_point_list "No such file"
	exit -1
    fi
else
    #output error and exit.
    echo "ERROR reading mount point list of clients:" $client_list "No such file"
    exit -1
fi

# Run iozone for all clients.
let "i=0"
for client in `cat $client_list`; do
    let "count=1"
    read_name=""
    write_name=""
    while [ "$count" -le "$num_runs" ]; do
	echo ${mount_points[$i]}
	echo "iozone -f${mount_points[$i]}/iozone_temp_largefile -Race -i0 -i1 -n"$min_filesize" -g"$max_filesize" -r"$record_size" -+n > "$PATH_TO_SAVE"single_client_"$min_filesize"_"$max_filesize"_run"$count""
	dsh -m $client -- "export RSH=ssh && iozone -f${mount_points[$i]}/iozone_temp_largefile -Race -i0 -i1 -n"$min_filesize" -g"$max_filesize" -r"$record_size" -+n > "$PATH_TO_SAVE"single_client_"$min_filesize"_"$max_filesize"_run"$count""
	dsh -m $client -- "rm -rf ${mount_points[$i]}/iozone_temp_largefile"
	dsh -m $client -- " rm -rf ${mount_points[$i]}/iozone_temp_large_file"	
	dsh -m $client -- "parse_singleclient_output.sh "$PATH_TO_SAVE"single_client_"$min_filesize"_"$max_filesize"_run"$count" write"
	dsh -m $client -- "parse_singleclient_output.sh "$PATH_TO_SAVE"single_client_"$min_filesize"_"$max_filesize"_run"$count" read"
	dsh -m $client -- "rm -rf "$PATH_TO_SAVE"single_client_autoreport_run"$count" "
	read_name="$read_name"' '"$PATH_TO_SAVE"read_single_client_"$min_filesize"_"$max_filesize"_run"$count".txt
	write_name="$write_name"' '"$PATH_TO_SAVE"write_single_client_"$min_filesize"_"$max_filesize"_run"$count".txt
	let "count=$count+1"
    done
    dsh -m $client -- "insert_iozone_singleclient $DB_SERVER $VERSION $FS "$4"_write \"$SAVE_AS\" 1 $client $num_runs$write_name"
    dsh -m $client -- "insert_iozone_singleclient $DB_SERVER $VERSION $FS "$4"_read \"$SAVE_AS\" 1 $client $num_runs$read_name"
    dsh -m $client -- "rm -rf $write_name $read_name"
    let "i=$i+1"
done
